@@ -3,15 +3,15 @@ package segments
 import (
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/mock"
-	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
 )
 
 func TestSpotifyStringPlayingSong(t *testing.T) {
 	expected := "\ue602 Candlemass - Spellbreaker"
-	env := new(mock.MockedEnvironment)
+	env := new(mock.Environment)
 	s := &Spotify{
 		MusicPlayer: MusicPlayer{
 			Artist: "Candlemass",
@@ -27,7 +27,7 @@ func TestSpotifyStringPlayingSong(t *testing.T) {
 
 func TestSpotifyStringStoppedSong(t *testing.T) {
 	expected := "\uf04d"
-	env := new(mock.MockedEnvironment)
+	env := new(mock.Environment)
 	s := &Spotify{
 		MusicPlayer: MusicPlayer{
 			Artist: "Candlemass",
