@@ -4,14 +4,14 @@ import (
 	"errors"
 	"path/filepath"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"gopkg.in/yaml.v3"
 )
 
 type TalosCTL struct {
 	props properties.Properties
-	env   platform.Environment
+	env   runtime.Environment
 
 	Context string `yaml:"context"`
 }
@@ -20,7 +20,7 @@ func (t *TalosCTL) Template() string {
 	return " {{ .Context}} "
 }
 
-func (t *TalosCTL) Init(props properties.Properties, env platform.Environment) {
+func (t *TalosCTL) Init(props properties.Properties, env runtime.Environment) {
 	t.props = props
 	t.env = env
 }
